#!/usr/bin/env bash
#
# List ports containing an option matching the first parameter to the script.
set -euo pipefail
IFS=$'\n\t'
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

: ${PORTSDIR:="/usr/ports"}

function main {
    if [ "$#" -ne 1 ]; then
        (>&2 echo "Pass exactly 1 option name to this script.")
        exit 1
    fi
    local find_option_name=$1
    local folder
    find_port_folders | while read folder; do
        set +e
        dump_port_options "$folder" | grep -qE "^${find_option_name}$"
        has_opt=$?;
        set -e
        if [ $has_opt -eq 0 ]; then
            echo "$folder"
        fi
    done
}

function find_port_folders {
    local mf
    find "$PORTSDIR" -type f -name Makefile -mindepth 3 -maxdepth 3 | sort | while read mf; do
        dirname "$mf"
    done
}

function dump_port_options {
    local folder="$1"
    local portopts=$(make -C "$folder" -V OPTIONS_DEFINE)
    echo "$portopts" | grep -oE --line-buffered '[^ ]*'
}

main "${@}"
